pub struct Options {
pub tests: Vec<String>,
pub workers: Option<usize>,
pub params: Vec<Variable>,
pub quiet: bool,
pub verbose: bool,
pub all: bool,
pub no_execute: bool,
pub search_paths: Vec<PathBuf>,
pub timeout: Option<u64>,
pub filter: Option<Regex>,
pub filter_out: Option<Regex>,
pub target: Option<Triple>,
}Fields
tests: Vec<String>The test files or directories to search for tests
workers: Option<usize>Run N tests in parallel
By default, this is automatically chosen to match the number of available CPUs
params: Vec<Variable>Add a user-defined parameter NAME with the given optional VALUE.
quiet: boolSuppress any output except for test failures.
verbose: boolShow more information on test failures, for example, the entire test output instead of just the result.
Each command is printed before it is executed, along with where the command was derived from.
all: boolEnable -v, but for all tests, not just failed tests
no_execute: boolDon’t execute any tests (assume PASS).
For example, this will still parse test cases for RUN commands, but will not actually execute those commands to run the tests.
search_paths: Vec<PathBuf>Specify an additional PATH to use when searching for executables in tests.
timeout: Option<u64>Spend at most N seconds running each individual test.
0 means no time limit, and is the default value.
filter: Option<Regex>Run only those tests whose name matches the given regular expression.
filter_out: Option<Regex>Exclude those tests whose name matches the given regular expression.
target: Option<Triple>If specified, will set available features based on the provided target triple.
Expects a string like ‘x86_64-apple-darwin’.
The default target is the host